param($installPath, $toolsPath, $package)
Write-Output "Running init.ps1"
Write-Output $installPath
Write-Output $toolsPath
Write-Output $package;

# find out where to put the files, we're going to create a deploy directory
# at the same level as the solution.

# create our deploy support directory if it doesn't exist yet
$rootDir = (Get-Item $installPath).parent.parent.fullname
Write-Output $rootDir
$deploySource = join-path $installPath 'tools/CodeGenerator'
Write-Output $deploySource

# destinination directory
$slnPath = [System.IO.Path]::GetDirectoryName($dte.Solution.FullName)
Write-Output $slnPath
$deployTarget = "$slnPath\CodeGenerator"
Write-Output $deployTarget


if (!(test-path $deployTarget)) {
	mkdir $deployTarget
}

# copy everything in there
Copy-Item "$deploySource/*" $deployTarget -Recurse -Force

# copy CodeGenEntitiesConfig.Deploy.xml to CodeGenEntitiesConfig.xml (if not exists)
$configXml = join-path $deployTarget 'CodeGenEntitiesConfig.xml'
if (!(test-path $configXml)) {
    Copy-Item "$deploySource/CodeGenEntitiesConfig.Deploy.xml" $configXml
}

# get the active solution
$solution2 = Get-Interface $dte.Solution ([EnvDTE80.Solution2])

# create a deploy solution folder if it doesn't exist
$deployFolder = $solution2.Projects | where-object { $_.ProjectName -eq "CodeGenerator" } | select -first 1

if(!$deployFolder) {
	$deployFolder = $solution2.AddSolutionFolder("CodeGenerator")
}

# add all our support deploy scripts to our Support solution folder

$folderItems = Get-Interface $deployFolder.ProjectItems ([EnvDTE.ProjectItems])

ls $deployTarget | foreach-object { 
	$folderItems.AddFromFile($_.FullName) > $null
} > $null
